summaryrefslogtreecommitdiffstats
path: root/src/H5Gnode.c
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2003-12-06 20:40:12 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2003-12-06 20:40:12 (GMT)
commit211baa5e46802352cac761533f3f9a0749f1dd6c (patch)
treeedbc0a099b27bbdc25bac11c3a925270b52b5cf8 /src/H5Gnode.c
parentf00ad1c5d6c592d9f559fbb5b39a45db28ba23aa (diff)
downloadhdf5-211baa5e46802352cac761533f3f9a0749f1dd6c.zip
hdf5-211baa5e46802352cac761533f3f9a0749f1dd6c.tar.gz
hdf5-211baa5e46802352cac761533f3f9a0749f1dd6c.tar.bz2
[svn-r7918] Purpose:
Code cleanup Description: Clean up compiler warnings, especially the 'FUNC' variable not used which comes out in production mode. Solution: Had to add a new FUNC_ENTER_NOAPI_NOINIT_NOFUNC macro for those non-API functions which don't need the 'FUNC' variable defined. (This will be _so_ much easier when C99 is standard on all our supposed platforms, since it has a __FUNC__ macro... ) Platforms tested: FreeBSD 4.9 (sleipnir) too minor for h5committest (although there were lots of files changed, the change was minor in each one)
Diffstat (limited to 'src/H5Gnode.c')
-rw-r--r--src/H5Gnode.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/H5Gnode.c b/src/H5Gnode.c
index 2440234..a7a23b3 100644
--- a/src/H5Gnode.c
+++ b/src/H5Gnode.c
@@ -161,8 +161,8 @@ H5FL_BLK_DEFINE_STATIC(symbol_node);
static size_t
H5G_node_sizeof_rkey(H5F_t *f, const void UNUSED * udata)
{
- /* Use FUNC_ENTER_NOINIT here to avoid performance issues */
- FUNC_ENTER_NOINIT(H5G_node_sizeof_rkey);
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5G_node_sizeof_rkey);
FUNC_LEAVE_NOAPI(H5F_SIZEOF_SIZE(f)); /*the name offset */
}
@@ -295,7 +295,7 @@ done:
static size_t
H5G_node_size(H5F_t *f)
{
- FUNC_ENTER_NOINIT(H5G_node_size);
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5G_node_size);
FUNC_LEAVE_NOAPI(H5G_NODE_SIZEOF_HDR(f) +
(2 * H5F_SYM_LEAF_K(f)) * H5G_SIZEOF_ENTRY(f));
@@ -516,7 +516,7 @@ done:
static herr_t
H5G_node_dest(H5F_t UNUSED *f, H5G_node_t *sym)
{
- FUNC_ENTER_NOINIT(H5G_node_dest);
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5G_node_dest);
/*
* Check arguments.
@@ -554,7 +554,7 @@ H5G_node_clear(H5G_node_t *sym)
{
int i; /* Local index variable */
- FUNC_ENTER_NOINIT(H5G_node_clear);
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5G_node_clear);
/*
* Check arguments.